//-------------------------------------------------------------------
//
// deHTML 1.01 Copyright (c)1995 Styx Nova SEL and Fredrik Wangel
//             All rights reserved.
//
// Converts a .HTML file into normal text using the standard
// input and output streams, ie redirectable using < and >.
//
// HISTORY:
// 1995.11.26, v1.00 : First version, supports HTML 3.0, no break checking.
//                     No checking on for example <CENTER> and such
//                     (ie no layout of the text is done, other than with
//                      the spaces and tabs of the input file).
//
// 1996.04.22, v1.01 : Fixed bug with &#nnn, # was missing. Oooops :-)
//
//-------------------------------------------------------------------

#include <iostream.h>
#include <string.h>

#define COPYRIGHT "Copyright (c)1995-96 Styx Nova SEL and Fredrik Wangel, All rights reserved."
#define MAXBUF   256
#define RC_OKAY    0
#define RC_WARN    5
#define HTAB       9		// Horizontal TABulator
#define LF        10		// Line Feed
#define CHAR_255 255		// Small y with dieresis or umlaut mark

const char ver[] = "$VER: dehtml 1.01 (22.04.96) "COPYRIGHT;

char buffert[MAXBUF];
char ch;
int  rc = RC_OKAY;


void usage(void)
{
	cout << " NAME\ndeHTML -- Converts a .HTML file into normal text.\n\n VERSION\n1.01 Apr 22, 1996. "COPYRIGHT"\n\n";
	cout << " SYNOPSIS\ndeHTML\n\n FUNCTION\ndeHTML uses the standard input and output streams to convert ";
	cout << "a .HTML document \"on-the-fly\". It removes all the HTML codes and replaces the &XXX commands with the ";
	cout << "appropriate substitutions. It knows many of the codes defined in HTML 3.0.\n\n";
	cout << " INPUTS\nNone. Use the normal input redirection to convert a file.\n\n";
	cout << " RESULTS\nThe cleansed .HTML file in ISO 8859/1 Latin-1 text format.\n";
	cout << "Returncode is set to OKAY (0) if no error has occured.\n";
	cout << "WARN (5) is set if any arguments other than ?, -?, -h or -H are given.\n";
	rc = RC_WARN;
}

void translate(void)
{
	while(cin.get(ch)) {
		if(ch == '&') {
			cin.getline(buffert, MAXBUF, ';');
			if(!strcmp(buffert, "lt"))cout.put('<');
			if(!strcmp(buffert, "gt"))cout.put('>');
			if(!strcmp(buffert, "copy"))cout.put('');
			if(!strcmp(buffert, "amp"))cout.put('&');
			if(!strcmp(buffert, "quot"))cout.put('"');
			if(!strcmp(buffert, "Aacute"))cout.put('');
			if(!strcmp(buffert, "Agrave"))cout.put('');
			if(!strcmp(buffert, "Acirc"))cout.put('');
			if(!strcmp(buffert, "Atilde"))cout.put('');
			if(!strcmp(buffert, "Aring"))cout.put('');
			if(!strcmp(buffert, "Auml"))cout.put('');
			if(!strcmp(buffert, "AElig"))cout.put('');
			if(!strcmp(buffert, "Ccedil"))cout.put('');
			if(!strcmp(buffert, "Eacute"))cout.put('');
			if(!strcmp(buffert, "Egrave"))cout.put('');
			if(!strcmp(buffert, "Ecirc"))cout.put('');
			if(!strcmp(buffert, "Euml"))cout.put('');
			if(!strcmp(buffert, "Iacute"))cout.put('');
			if(!strcmp(buffert, "Igrave"))cout.put('');
			if(!strcmp(buffert, "Icirc"))cout.put('');
			if(!strcmp(buffert, "Iuml"))cout.put('');
			if(!strcmp(buffert, "ETH"))cout.put('');
			if(!strcmp(buffert, "Ntilde"))cout.put('');
			if(!strcmp(buffert, "Oacute"))cout.put('');
			if(!strcmp(buffert, "Ograve"))cout.put('');
			if(!strcmp(buffert, "Ocirc"))cout.put('');
			if(!strcmp(buffert, "Otilde"))cout.put('');
			if(!strcmp(buffert, "Ouml"))cout.put('');
			if(!strcmp(buffert, "Oslash"))cout.put('');
			if(!strcmp(buffert, "Uuml"))cout.put('');
			if(!strcmp(buffert, "Yacute"))cout.put('');
			if(!strcmp(buffert, "THORN"))cout.put('');
			if(!strcmp(buffert, "szlig"))cout.put('');
			if(!strcmp(buffert, "aacute"))cout.put('');
			if(!strcmp(buffert, "agrave"))cout.put('');
			if(!strcmp(buffert, "acirc"))cout.put('');
			if(!strcmp(buffert, "atilde"))cout.put('');
			if(!strcmp(buffert, "aring"))cout.put('');
			if(!strcmp(buffert, "auml"))cout.put('');
			if(!strcmp(buffert, "aelig"))cout.put('');
			if(!strcmp(buffert, "ccedil"))cout.put('');
			if(!strcmp(buffert, "eacute"))cout.put('');
			if(!strcmp(buffert, "egrave"))cout.put('');
			if(!strcmp(buffert, "ecirc"))cout.put('');
			if(!strcmp(buffert, "euml"))cout.put('');
			if(!strcmp(buffert, "iacute"))cout.put('');
			if(!strcmp(buffert, "igrave"))cout.put('');
			if(!strcmp(buffert, "icirc"))cout.put('');
			if(!strcmp(buffert, "iuml"))cout.put('');
			if(!strcmp(buffert, "eth"))cout.put('');
			if(!strcmp(buffert, "ntilde"))cout.put('');
			if(!strcmp(buffert, "oacute"))cout.put('');
			if(!strcmp(buffert, "ograve"))cout.put('');
			if(!strcmp(buffert, "ocirc"))cout.put('');
			if(!strcmp(buffert, "otilde"))cout.put('');
			if(!strcmp(buffert, "ouml"))cout.put('');
			if(!strcmp(buffert, "oslash"))cout.put('');
			if(!strcmp(buffert, "uacute"))cout.put('');
			if(!strcmp(buffert, "ograve"))cout.put('');
			if(!strcmp(buffert, "ucirc"))cout.put('');
			if(!strcmp(buffert, "uuml"))cout.put('');
			if(!strcmp(buffert, "yacute"))cout.put('');
			if(!strcmp(buffert, "thorn"))cout.put('');
			if(!strcmp(buffert, "yuml"))cout.put(CHAR_255);
			if(!strcmp(buffert, "nbsp"))cout.put(' ');
			if(!strcmp(buffert, "ensp"))cout.put(' ');
			if(!strcmp(buffert, "emsp"))cout << "  ";
			if(!strcmp(buffert, "endash"))cout.put('/');
			if(!strcmp(buffert, "emdash"))cout.put('/');
			if(!strcmp(buffert, "#09"))cout.put(HTAB);
			if(!strcmp(buffert, "#10"))cout.put(LF);
			if(!strcmp(buffert, "#32"))cout.put(' ');
			if(!strcmp(buffert, "#33"))cout.put('!');
			if(!strcmp(buffert, "#34"))cout.put('"');
			if(!strcmp(buffert, "#35"))cout.put('#');
			if(!strcmp(buffert, "#36"))cout.put('$');
			if(!strcmp(buffert, "#37"))cout.put('%');
			if(!strcmp(buffert, "#38"))cout.put('&');
			if(!strcmp(buffert, "#39"))cout.put('\'');
			if(!strcmp(buffert, "#40"))cout.put('(');
			if(!strcmp(buffert, "#41"))cout.put(')');
			if(!strcmp(buffert, "#42"))cout.put('*');
			if(!strcmp(buffert, "#43"))cout.put('+');
			if(!strcmp(buffert, "#44"))cout.put(',');
			if(!strcmp(buffert, "#45"))cout.put('-');
			if(!strcmp(buffert, "#46"))cout.put('.');
			if(!strcmp(buffert, "#47"))cout.put('/');
			if(!strcmp(buffert, "#48"))cout.put('0');
			if(!strcmp(buffert, "#49"))cout.put('1');
			if(!strcmp(buffert, "#50"))cout.put('2');
			if(!strcmp(buffert, "#51"))cout.put('3');
			if(!strcmp(buffert, "#52"))cout.put('4');
			if(!strcmp(buffert, "#53"))cout.put('5');
			if(!strcmp(buffert, "#54"))cout.put('6');
			if(!strcmp(buffert, "#55"))cout.put('7');
			if(!strcmp(buffert, "#56"))cout.put('8');
			if(!strcmp(buffert, "#57"))cout.put('9');
			if(!strcmp(buffert, "#58"))cout.put(':');
			if(!strcmp(buffert, "#59"))cout.put(';');
			if(!strcmp(buffert, "#60"))cout.put('<');
			if(!strcmp(buffert, "#61"))cout.put('=');
			if(!strcmp(buffert, "#62"))cout.put('>');
			if(!strcmp(buffert, "#63"))cout.put('?');
			if(!strcmp(buffert, "#64"))cout.put('@');
			if(!strcmp(buffert, "#65"))cout.put('A');
			if(!strcmp(buffert, "#66"))cout.put('B');
			if(!strcmp(buffert, "#67"))cout.put('C');
			if(!strcmp(buffert, "#68"))cout.put('D');
			if(!strcmp(buffert, "#69"))cout.put('E');
			if(!strcmp(buffert, "#70"))cout.put('F');
			if(!strcmp(buffert, "#71"))cout.put('G');
			if(!strcmp(buffert, "#72"))cout.put('H');
			if(!strcmp(buffert, "#73"))cout.put('I');
			if(!strcmp(buffert, "#74"))cout.put('J');
			if(!strcmp(buffert, "#75"))cout.put('K');
			if(!strcmp(buffert, "#76"))cout.put('L');
			if(!strcmp(buffert, "#77"))cout.put('M');
			if(!strcmp(buffert, "#78"))cout.put('N');
			if(!strcmp(buffert, "#79"))cout.put('O');
			if(!strcmp(buffert, "#80"))cout.put('P');
			if(!strcmp(buffert, "#81"))cout.put('Q');
			if(!strcmp(buffert, "#82"))cout.put('R');
			if(!strcmp(buffert, "#83"))cout.put('S');
			if(!strcmp(buffert, "#84"))cout.put('T');
			if(!strcmp(buffert, "#85"))cout.put('U');
			if(!strcmp(buffert, "#86"))cout.put('V');
			if(!strcmp(buffert, "#87"))cout.put('W');
			if(!strcmp(buffert, "#88"))cout.put('X');
			if(!strcmp(buffert, "#89"))cout.put('Y');
			if(!strcmp(buffert, "#90"))cout.put('Z');
			if(!strcmp(buffert, "#91"))cout.put('[');
			if(!strcmp(buffert, "#92"))cout.put('\\');
			if(!strcmp(buffert, "#93"))cout.put(']');
			if(!strcmp(buffert, "#94"))cout.put('^');
			if(!strcmp(buffert, "#95"))cout.put('_');
			if(!strcmp(buffert, "#96"))cout.put('`');
			if(!strcmp(buffert, "#97"))cout.put('a');
			if(!strcmp(buffert, "#98"))cout.put('b');
			if(!strcmp(buffert, "#99"))cout.put('c');
			if(!strcmp(buffert, "#100"))cout.put('d');
			if(!strcmp(buffert, "#101"))cout.put('e');
			if(!strcmp(buffert, "#102"))cout.put('f');
			if(!strcmp(buffert, "#103"))cout.put('g');
			if(!strcmp(buffert, "#104"))cout.put('h');
			if(!strcmp(buffert, "#105"))cout.put('i');
			if(!strcmp(buffert, "#106"))cout.put('j');
			if(!strcmp(buffert, "#107"))cout.put('k');
			if(!strcmp(buffert, "#108"))cout.put('l');
			if(!strcmp(buffert, "#109"))cout.put('m');
			if(!strcmp(buffert, "#110"))cout.put('n');
			if(!strcmp(buffert, "#111"))cout.put('o');
			if(!strcmp(buffert, "#112"))cout.put('p');
			if(!strcmp(buffert, "#113"))cout.put('q');
			if(!strcmp(buffert, "#114"))cout.put('r');
			if(!strcmp(buffert, "#115"))cout.put('s');
			if(!strcmp(buffert, "#116"))cout.put('t');
			if(!strcmp(buffert, "#117"))cout.put('u');
			if(!strcmp(buffert, "#118"))cout.put('v');
			if(!strcmp(buffert, "#119"))cout.put('w');
			if(!strcmp(buffert, "#120"))cout.put('x');
			if(!strcmp(buffert, "#121"))cout.put('y');
			if(!strcmp(buffert, "#122"))cout.put('z');
			if(!strcmp(buffert, "#123"))cout.put('{');
			if(!strcmp(buffert, "#124"))cout.put('|');
			if(!strcmp(buffert, "#125"))cout.put('}');
			if(!strcmp(buffert, "#126"))cout.put('~');
			if(!strcmp(buffert, "#161"))cout.put('');
			if(!strcmp(buffert, "#162"))cout.put('');
			if(!strcmp(buffert, "#163"))cout.put('');
			if(!strcmp(buffert, "#164"))cout.put('');
			if(!strcmp(buffert, "#165"))cout.put('');
			if(!strcmp(buffert, "#166"))cout.put('');
			if(!strcmp(buffert, "#167"))cout.put('');
			if(!strcmp(buffert, "#168"))cout.put('');
			if(!strcmp(buffert, "#169"))cout.put('');
			if(!strcmp(buffert, "#170"))cout.put('');
			if(!strcmp(buffert, "#171"))cout.put('');
			if(!strcmp(buffert, "#172"))cout.put('');
			if(!strcmp(buffert, "#173"))cout.put('');
			if(!strcmp(buffert, "#174"))cout.put('');
			if(!strcmp(buffert, "#175"))cout.put('');
			if(!strcmp(buffert, "#176"))cout.put('');
			if(!strcmp(buffert, "#177"))cout.put('');
			if(!strcmp(buffert, "#178"))cout.put('');
			if(!strcmp(buffert, "#179"))cout.put('');
			if(!strcmp(buffert, "#180"))cout.put('');
			if(!strcmp(buffert, "#181"))cout.put('');
			if(!strcmp(buffert, "#182"))cout.put('');
			if(!strcmp(buffert, "#183"))cout.put('');
			if(!strcmp(buffert, "#184"))cout.put('');
			if(!strcmp(buffert, "#185"))cout.put('');
			if(!strcmp(buffert, "#186"))cout.put('');
			if(!strcmp(buffert, "#187"))cout.put('');
			if(!strcmp(buffert, "#188"))cout.put('');
			if(!strcmp(buffert, "#189"))cout.put('');
			if(!strcmp(buffert, "#190"))cout.put('');
			if(!strcmp(buffert, "#191"))cout.put('');
			if(!strcmp(buffert, "#192"))cout.put('');
			if(!strcmp(buffert, "#193"))cout.put('');
			if(!strcmp(buffert, "#194"))cout.put('');
			if(!strcmp(buffert, "#195"))cout.put('');
			if(!strcmp(buffert, "#196"))cout.put('');
			if(!strcmp(buffert, "#197"))cout.put('');
			if(!strcmp(buffert, "#198"))cout.put('');
			if(!strcmp(buffert, "#199"))cout.put('');
			if(!strcmp(buffert, "#200"))cout.put('');
			if(!strcmp(buffert, "#201"))cout.put('');
			if(!strcmp(buffert, "#202"))cout.put('');
			if(!strcmp(buffert, "#203"))cout.put('');
			if(!strcmp(buffert, "#204"))cout.put('');
			if(!strcmp(buffert, "#205"))cout.put('');
			if(!strcmp(buffert, "#206"))cout.put('');
			if(!strcmp(buffert, "#207"))cout.put('');
			if(!strcmp(buffert, "#208"))cout.put('');
			if(!strcmp(buffert, "#209"))cout.put('');
			if(!strcmp(buffert, "#210"))cout.put('');
			if(!strcmp(buffert, "#211"))cout.put('');
			if(!strcmp(buffert, "#212"))cout.put('');
			if(!strcmp(buffert, "#213"))cout.put('');
			if(!strcmp(buffert, "#214"))cout.put('');
			if(!strcmp(buffert, "#215"))cout.put('');
			if(!strcmp(buffert, "#216"))cout.put('');
			if(!strcmp(buffert, "#217"))cout.put('');
			if(!strcmp(buffert, "#218"))cout.put('');
			if(!strcmp(buffert, "#219"))cout.put('');
			if(!strcmp(buffert, "#220"))cout.put('');
			if(!strcmp(buffert, "#221"))cout.put('');
			if(!strcmp(buffert, "#222"))cout.put('');
			if(!strcmp(buffert, "#223"))cout.put('');
			if(!strcmp(buffert, "#224"))cout.put('');
			if(!strcmp(buffert, "#225"))cout.put('');
			if(!strcmp(buffert, "#226"))cout.put('');
			if(!strcmp(buffert, "#227"))cout.put('');
			if(!strcmp(buffert, "#228"))cout.put('');
			if(!strcmp(buffert, "#229"))cout.put('');
			if(!strcmp(buffert, "#230"))cout.put('');
			if(!strcmp(buffert, "#231"))cout.put('');
			if(!strcmp(buffert, "#232"))cout.put('');
			if(!strcmp(buffert, "#233"))cout.put('');
			if(!strcmp(buffert, "#234"))cout.put('');
			if(!strcmp(buffert, "#235"))cout.put('');
			if(!strcmp(buffert, "#236"))cout.put('');
			if(!strcmp(buffert, "#237"))cout.put('');
			if(!strcmp(buffert, "#238"))cout.put('');
			if(!strcmp(buffert, "#239"))cout.put('');
			if(!strcmp(buffert, "#240"))cout.put('');
			if(!strcmp(buffert, "#241"))cout.put('');
			if(!strcmp(buffert, "#242"))cout.put('');
			if(!strcmp(buffert, "#243"))cout.put('');
			if(!strcmp(buffert, "#244"))cout.put('');
			if(!strcmp(buffert, "#245"))cout.put('');
			if(!strcmp(buffert, "#246"))cout.put('');
			if(!strcmp(buffert, "#247"))cout.put('');
			if(!strcmp(buffert, "#248"))cout.put('');
			if(!strcmp(buffert, "#249"))cout.put('');
			if(!strcmp(buffert, "#250"))cout.put('');
			if(!strcmp(buffert, "#251"))cout.put('');
			if(!strcmp(buffert, "#252"))cout.put('');
			if(!strcmp(buffert, "#253"))cout.put('');
			if(!strcmp(buffert, "#254"))cout.put('');
			if(!strcmp(buffert, "#255"))cout.put(CHAR_255);
			if(buffert[0] == ' ') cout << "&" << buffert << ";";
		}
		else
			if(ch == '<')
				cin.getline(buffert, MAXBUF, '>');
			else
				cout.put(ch);
	}
}
//translate()


int main(int argc, char *argv[])
{
	if((argc!=1)||(argv[1]=="?")||(argv[1]=="-?")||(argv[1]=="-h")||(argv[1]=="-H"))
		usage();
	else
		translate();
	return rc;
}
// main()
